==> nextGenShinyApps_1.6.tar.gz: nextGenShinyApps/README.md <==
# nextGenShinyApps: Tools in R for building the next generation of Shiny applications and responsive dashboards <img src="https://coursewhiz.org/shinyappsampleso/hex-nextGenShinyApps.png" width="300" align="right" >
## Official website: https://nextgenshinyapps.obi.obianom.com
### Other packages required for nextGenShinyApps: https://depends.rpkg.net/package/nextGenShinyApps

[![CRAN\_Status\_Badge](https://www.r-pkg.org/badges/version/nextGenShinyApps)](https://cran.r-project.org/package=nextGenShinyApps)

![](https://nextgenshinyapps.obi.obianom.com/nextgenshinyapp-3.png)
![](https://nextgenshinyapps.obi.obianom.com/designs/card-design.png)



## R package installation and usage
The nextGenShinyApps package is available on CRAN and can be installed as shown below

### Install package from CRAN

`install.packages(nextGenShinyApps)`

### Attach library 

`library(nextGenShinyApps)`

### Get started with some of the examples

`load.example("Card")`

`load.example("Plain")`

`load.example("noSideBar")`

`load.example("Tab")`

`load.example("Modal")`

`load.example("Alert")`

`load.example("Accordion")`


## Sample Demo Output 1

### View the Shiny app demo for Cards

[Link to demo](https://r2apps.shinyapps.io/nextgenshinyapps-card/)

### Image of what it looks like

![](https://nextgenshinyapps.obi.obianom.com/nextgenshinyapps.png)

## Sample Demo Output 2

### View the Shiny app demo for Tabs

[Link to demo](https://r2apps.shinyapps.io/nextgenshinyapps-tab/)

### Image of what it looks like

![](https://nextgenshinyapps.obi.obianom.com/nextgenshinyapps3.png)

## Sample Demo Output 3

![](https://nextgenshinyapps.obi.obianom.com/nextgenshinyapps1.png)


## Tutorial

Check R CRAN link for vignettes
 
## More information
 
 - https://coursewhiz.org/mainsite/nextgenshinyapps

## Statistic

[![](https://cranlogs.r-pkg.org/badges/nextGenShinyApps)](https://cran.r-project.org/package=nextGenShinyApps)

==> nextGenShinyApps_2.0.tar.gz: nextGenShinyApps/README.md <==
<img src="https://nextgenshinyapps.obi.obianom.com/adslogo2.png" width = "500">

# nextGenShinyApps: Craft Exceptional R Shiny Dashboards with Novel Responsive Tools <img src="https://coursewhiz.org/shinyappsampleso/hex-nextGenShinyApps.png" width="200" align="right" >
## Official website: https://nextgenshinyapps.obi.obianom.com
### Other packages required for nextGenShinyApps: https://depends.rpkg.net/package/nextGenShinyApps

### Get started with sample R codes: <br>https://github.com/oobianom/nextGenShinyApps-Boilerplate-BlankApp

__Please note that the nextGenShinyApps 1.7 is NOW compatible with the htmlwidgets,rhandsontable and plotly packages. This is being worked on, but there is not currently a completion date.__

[![CRAN\_Status\_Badge](https://www.r-pkg.org/badges/version/nextGenShinyApps)](https://cran.r-project.org/package=nextGenShinyApps)

![](https://nextgenshinyapps.obi.obianom.com/nextgenshinyapp-3.png)
![](https://nextgenshinyapps.obi.obianom.com/designs/card-design.png)



## R package installation and usage
The nextGenShinyApps package is available on CRAN and can be installed as shown below

### Install package from CRAN

`install.packages(nextGenShinyApps)`

### Attach library 

`library(nextGenShinyApps)`



### Get started by viewing some of the examples

`load.example("Card")`

`load.example("Plain")`

`load.example("noSideBar")`

`load.example("Tab")`

`load.example("Modal")`

`load.example("Alert")`

`load.example("Accordion")`


## Sample Demo Output 1

### View the Shiny app demo for Cards

[Link to demo](https://r2apps.shinyapps.io/nextgenshinyapps-card/)

### Image of what it looks like

![](https://nextgenshinyapps.obi.obianom.com/nextgenshinyapps.png)

## Sample Demo Output 2

### View the Shiny app demo for Tabs

[Link to demo](https://r2apps.shinyapps.io/nextgenshinyapps-tab/)

### Image of what it looks like

![](https://nextgenshinyapps.obi.obianom.com/nextgenshinyapps3.png)

## Sample Demo Output 3

![](https://nextgenshinyapps.obi.obianom.com/nextgenshinyapps1.png)


## Tutorial

Check R CRAN link for vignettes
 
## More information
 
 - https://coursewhiz.org/mainsite/nextgenshinyapps

## Statistic

[![](https://cranlogs.r-pkg.org/badges/nextGenShinyApps)](https://cran.r-project.org/package=nextGenShinyApps)
